aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGuido Günther <agx@sigxcpu.org>2014-05-16 19:51:26 +0200
committerGuido Günther <agx@sigxcpu.org>2014-05-16 19:51:56 +0200
commitb0390d15c9d77303a607e4b760771c71f6b7d971 (patch)
tree801cce82004fdf11934484ccd2a62c6fcd8006c4
parent817976e1117228641e93b76e4aee350f51316caf (diff)
Fix comitter vs committer typos
Thanks: Sandro Tosi Closes: #748339
-rw-r--r--docs/manpages/gbp-import-dsc.sgml4
-rw-r--r--gbp/config.py4
-rw-r--r--gbp/deb/git.py2
-rw-r--r--gbp/git/modifier.py8
-rw-r--r--gbp/git/repository.py2
-rw-r--r--gbp/scripts/dch.py2
-rw-r--r--tests/test_GitModifier.py2
7 files changed, 12 insertions, 12 deletions
diff --git a/docs/manpages/gbp-import-dsc.sgml b/docs/manpages/gbp-import-dsc.sgml
index 98f70e72..2d186ed8 100644
--- a/docs/manpages/gbp-import-dsc.sgml
+++ b/docs/manpages/gbp-import-dsc.sgml
@@ -169,7 +169,7 @@
</term>
<listitem>
<para>When importing the Debian patch, use the author identity as
- comitter identity.</para>
+ committer identity.</para>
</listitem>
</varlistentry>
<varlistentry>
@@ -177,7 +177,7 @@
</term>
<listitem>
<para>When importing the Debian patch, use the author date as
- comitter date. <warning><para>Git will subtly misbehave if the
+ committer date. <warning><para>Git will subtly misbehave if the
committer date of a commit is not later than or equal to all
its parents.</para></warning></para>
</listitem>
diff --git a/gbp/config.py b/gbp/config.py
index fc31076e..3fa59186 100644
--- a/gbp/config.py
+++ b/gbp/config.py
@@ -249,10 +249,10 @@ class GbpOptionParser(OptionParser):
("Set up tracking for remote branches, "
"default is '%(track)s'"),
'author-is-committer':
- ("Use the authors's name also as the comitter's name, "
+ ("Use the authors's name also as the committer's name, "
"default is '%(author-is-committer)s'"),
'author-date-is-committer-date':
- ("Use the authors's date as the comitter's date, "
+ ("Use the authors's date as the committer's date, "
"default is '%(author-date-is-committer-date)s'"),
'create-missing-branches':
("Create missing branches automatically, "
diff --git a/gbp/deb/git.py b/gbp/deb/git.py
index 7a328bed..6105fe7d 100644
--- a/gbp/deb/git.py
+++ b/gbp/deb/git.py
@@ -1,6 +1,6 @@
# vim: set fileencoding=utf-8 :
#
-# (C) 2011 Guido Günther <agx@sigxcpu.org>
+# (C) 2011,2014 Guido Günther <agx@sigxcpu.org>
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
diff --git a/gbp/git/repository.py b/gbp/git/repository.py
index 10b90308..23f9482a 100644
--- a/gbp/git/repository.py
+++ b/gbp/git/repository.py
@@ -1408,7 +1408,7 @@ class GitRepository(object):
@param parents: parents of this commit
@param author: authorship information
@type author: C{dict} with keys 'name' and 'email' or L{GitModifier}
- @param committer: comitter information
+ @param committer: committer information
@type committer: C{dict} with keys 'name' and 'email'
"""
extra_env = {}
diff --git a/gbp/scripts/dch.py b/gbp/scripts/dch.py
index f36f2877..c0344805 100644
--- a/gbp/scripts/dch.py
+++ b/gbp/scripts/dch.py
@@ -66,7 +66,7 @@ def get_author_email(repo, use_git_config):
def fixup_section(repo, git_author, options, dch_options):
"""
- Fixup the changelog header and trailer's comitter and email address
+ Fixup the changelog header and trailer's committer and email address
It might otherwise point to the last git committer instead of the person
creating the changelog
diff --git a/tests/test_GitModifier.py b/tests/test_GitModifier.py
index 1a28c0a8..0a05d4b8 100644
--- a/tests/test_GitModifier.py
+++ b/tests/test_GitModifier.py
@@ -26,7 +26,7 @@ def test_author():
>>> modifier._get_env('foo')
Traceback (most recent call last):
...
- GitModifierError: Neither comitter nor author
+ GitModifierError: Neither committer nor author
>>> modifier['name']
'foo'
>>> modifier['email']
diff --git a/gbp/git/modifier.py b/gbp/git/modifier.py
index bc986491..2452e0b5 100644
--- a/gbp/git/modifier.py
+++ b/gbp/git/modifier.py
@@ -41,7 +41,7 @@ class GitTz(datetime.tzinfo):
return datetime.timedelta(0)
class GitModifier(object):
- """Stores authorship/comitter information"""
+ """Stores authorship/committer information"""
def __init__(self, name=None, email=None, date=None):
"""
@param name: the modifier's name
@@ -77,10 +77,10 @@ class GitModifier(object):
"datetime object or git raw date" % date)
def _get_env(self, who):
"""Get author or comitter information as env var dictionary"""
who = who.upper()
if who not in ['AUTHOR', 'COMMITTER']:
- raise GitModifierError("Neither comitter nor author")
+ raise GitModifierError("Neither committer nor author")
extra_env = {}
if self.name:
@@ -130,7 +130,7 @@ class GitModifier(object):
def get_committer_env(self):
"""
Get env vars for comitter information
>>> g = GitModifier("foo", "bar")
>>> g.get_committer_env()
@@ -77,10 +77,10 @@ class GitModifier(object):
"datetime object or git raw date" % date)
def _get_env(self, who):
- """Get author or comitter information as env var dictionary"""
+ """Get author or committer information as env var dictionary"""
who = who.upper()
if who not in ['AUTHOR', 'COMMITTER']:
@@ -130,7 +130,7 @@ class GitModifier(object):
def get_committer_env(self):
"""
- Get env vars for comitter information
+ Get env vars for committer information
>>> g = GitModifier("foo", "bar")
>>> g.get_committer_env()